package com.example.blt_nfc

import android.app.Application
import androidx.lifecycle.AndroidViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow


data class StateType(
    val isNFCAvailable: Boolean = false,
    val isNFCEnabled: Boolean = false,
    val records: String = "",
    val techList: String = "",

    val isWriting: Boolean = false,
    val messageToWrite: String = "Hello, world!",
)


class NFCViewModel(application: Application) : AndroidViewModel(application) {

    private val _state = MutableStateFlow(StateType())
    val state: StateFlow<StateType> = _state.asStateFlow()

    fun updateIsNFCAvailable(isAvailable: Boolean){
        _state.value = _state.value.copy(isNFCAvailable = isAvailable)
    }
    fun updateIsNFCEnabled(isEnabled: Boolean){
        _state.value = _state.value.copy(isNFCEnabled = isEnabled)
    }
    fun updateRecords(newRecords: String) {
        _state.value = _state.value.copy(records = newRecords)
    }
    fun updateTechList(newTechList: String){
        _state.value = _state.value.copy(techList = newTechList)
    }
    fun updateIsWriting(isWriting: Boolean){
        _state.value = _state.value.copy(isWriting = isWriting)
    }
    fun updateMessageToWrite(newMessage: String){
        _state.value = _state.value.copy(messageToWrite = newMessage)
    }

    fun clearState(){
        _state.value = StateType().copy(isNFCAvailable = _state.value.isNFCAvailable, isNFCEnabled = _state.value.isNFCEnabled, messageToWrite = "")
    }
}